#!/bin/bash -l

module load singularity/2.4.2

function _log()
{
    echo "[INFO] $(hostname):$(date) $*" >> bootstrap.log
}

# set -euo pipefail
# set -x

_log "bootstrap"
_log "parameters: $@"

nargs=$#
_log "nargs: $nargs"
_log "last arg: ${!nargs}"

# params for singularity images:
# $1 - { get_input: sregistry_storage }
# $2 - { get_input: singularity_image_filename - aka collection/}
# $3 - { get_input: singularity_image_uri }
# $4 - { get_input: singularity_image_cleanup }
# $5 - { get_input: sregistry_client }
# $6 - { get_input: sregistry_secrets }
# $7 - { get_input: sregistry_url }
# $8 - { get_input: sregistry_image }

export SREGISTRY_STORAGE=$1

IMAGE_NAME=$2
IMAGE_URI=$3
IMAGE_CLEANUP=$4

export SREGISTRY_CLIENT=$5
export SREGISTRY_CLIENT_SECRETS=$6

SREGISTRY_URL=$7
SREGISTRY_IMAGE=$8

_log "${SREGISTRY_URL}"
_log "${SREGISTRY_IMAGE}"

# module should be optional:
isModule=$(compgen -A function | grep  module)
if [ "$isModule" != "" ]; then
    module load singularity
fi

# Singularity image retrieved from
# https://www.singularity-hub.org/collections/253

_log "CURRENT_WORKIR=$CURRENT_WORKDIR"
_log "IMAGE_NAME=$IMAGE_NAME"
_log "IMAGE_URI=$IMAGE_URI"

_log "SREGISTRY_STORAGE=${SREGISTRY_STORAGE}"
_log "SREGISTRY_CLIENT=${SREGISTRY_CLIENT}"
_log "SREGISTRY_CLIENT_SECRETS=${SREGISTRY_CLIENT_SECRETS}"
_log "SREGISTRY_URL=${SREGISTRY_URL}"
_log "SREGISTRY_IMAGE=${SREGISTRY_IMAGE}"

# Check if secrets exist
if [ ! -f ${SREGISTRY_CLIENT_SECRETS} ]; then
    _log "No SRegistry secrets found: ${SREGISTRY_CLIENT_SECRETS}"
    _log "You have to upload such file first on HPC resources"
    exit 1
fi

if [ ! -d ${SREGISTRY_STORAGE} ]; then
    mkdir -p ${SREGISTRY_STORAGE}
fi

_log "Get $IMAGE_URI ($IMAGE_NAME) using intermediate shub://${SREGISTRY_URL}/${SREGISTRY_IMAGE}"
# On Cesga:
singularity run -B /mnt shub://${SREGISTRY_URL}/${SREGISTRY_IMAGE} --quiet pull ${IMAGE_URI} 2>&1
status=$?
_log "singularity run -B /mnt shub://${SREGISTRY_URL}/${SREGISTRY_IMAGE} pull ${IMAGE_URI} (status=$status)"
if [ $status != "0" ]; then
    echo "singularity run -B /mnt shub://${SREGISTRY_URL}/${SREGISTRY_IMAGE} pull ${IMAGE_URI}: FAILS"
    exit 1
fi

_log "Bootstrap finished succesfully!"
