#!/bin/bash -l

# set -euo pipefail
# set -x


module load singularity/2.4.2

LOG_FILE=bootstrap.log
function _log()
{
    echo "[INFO] $(hostname):$(date) $*" >> bootstrap.log
}
function _export()
{
    export $1
    _log "export $1"
}

_log "revert"
_log "parameters: $@"

nargs=$#
_log "nargs: $nargs"
_log "last arg: ${!nargs}"

# params for singularity images:
# $1 - { get_input: sregistry_storage }
# $2 - { get_input: singularity_image_filename - aka collection/}
# $3 - { get_input: singularity_image_uri }
# $4 - { get_input: singularity_image_cleanup }
# $5 - { get_input: sregistry_client }
# $6 - { get_input: sregistry_secrets }
# $7 - { get_input: sregistry_url }
# $8 - { get_input: sregistry_image }

_export SREGISTRY_STORAGE=$1

IMAGE_NAME=$2
IMAGE_URI=$3
IMAGE_CLEANUP=$4

_export SREGISTRY_CLIENT=$5
_export SREGISTRY_CLIENT_SECRETS=$6

SREGISTRY_URL=$7
SREGISTRY_IMAGE=$8

# module should be optional:
isModule=$(compgen -A function | grep  module)
_log "isModule=${isModule}"
if [ "$isModule" != "" ]; then
    module load singularity
fi


# Remove image from the client ${SREGISTRY_STORAGE}
_log "IMAGE_CLEANUP=${IMAGE_CLEANUP}"
if [ $IMAGE_CLEANUP = "true"  ]; then
   isSregistry=$(which sregistry 2>&1 > /dev/null)
   _log "isSregistry=$isSregistry"
   if  [ "$isSregistry" != "" ] && [ ${SREGISTRY_URL} != "" ] && [ ${SREGISTRY_IMAGE} != "" ]; then
       sregistry rm ${IMAGE_URI} >> ${LOG_FILE}
   else
       singularity run -B /mnt shub://${SREGISTRY_URL}/${SREGISTRY_IMAGE} rmi ${IMAGE_URI} >> ${LOG_FILE}
   fi
fi
